# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2024 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

def calculate_indirect_operating_costs(dict_ac_data, dict_operating_costs, runtime_output):
    """Calculate indirect operating costs.

    Note: No calculation method for indirect operating costs (IOC) implemented.

    This function adds the 'indirect_operating_costs' dict to the 'dict_operating_costs' that contains the following
    parameters:
        - float indirect_operating_costs: Indirect operating costs in EUR

    :param dict dict_ac_data: Dict containing parameters and values from aircraft exchange and module config file
    :param dict dict_operating_costs: Dict containing parameters from cost estimation calculation
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :return dict dict_operating_costs: Dict containing parameters from cost estimation calculation
    """
    # Extract necessary variables from 'dict_ac_data'.
    # Extract necessary values from 'dict_operating_costs'.

    # Calculate indirect operating costs.
    indirect_operating_costs = 0

    # Print.
    runtime_output.warning('No calculation method for indirect operating costs (IOC) implemented. IOC set to 0.')

    # Prepare output data.
    dict_operating_costs['indirect_operating_costs'] = {}
    dict_operating_costs['indirect_operating_costs']['indirect_operating_costs'] = indirect_operating_costs

    return dict_operating_costs
