/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "missionConfig.h"
#include <aixml/node.h>

using std::string;

MissionConfig::MissionConfig()
    :
    keroseneMethodHC(""),
    kersoseneMethodCO(""),
    keroseneMethodNOx(""),
    keroseneMethodSoot(""),
    relativeHumidity(0.) {}

void MissionConfig::readAllConfigData(const node& configXML) {
    const node& mission(configXML.at("program_settings/standard_strategy/emission_calculation/mission_emissions"));

    keroseneMethodHC = EndnodeReadOnly<string>("emission_methods/kerosene/HC_method_selector").read(mission).value();
    kersoseneMethodCO = EndnodeReadOnly<string>("emission_methods/kerosene/CO_method_selector").read(mission).value();
    keroseneMethodNOx = EndnodeReadOnly<string>("emission_methods/kerosene/NOx_method_selector").read(mission).value();
    keroseneMethodSoot = EndnodeReadOnly<string>("emission_methods/kerosene/soot_method_selector").read(mission).value();
    hydrogenMethodNOx = EndnodeReadOnly<string>("emission_methods/hydrogen_combustion/NOx_method_selector").read(mission).value();
    relativeHumidity = EndnodeReadOnly<double>("relative_humidity").read(mission).value();
}

MissionConfig::~MissionConfig() {
    //dtor
}

