/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */
#include <string>
#include "../../standard_strategy.h"
#include "../../../toolinfo.h"
#include <moduleBasics/plot.h>

void StandardStrategy::generateMissionEmissionsPlot(const std::string& missionType) {
    Mission* theMission = nullptr;
    if (missionType == "study") {
        theMission = &theStudyMission;
    } else if (missionType == "design") {
        theMission = &theDesignMission;
    }
    std::vector<double> CO2_flow;
    std::vector<double> H2O_flow;
    std::vector<double> SO2_flow;
    std::vector<double> SO4_flow;
    std::vector<double> NOx_flow;
    std::vector<double> HC_flow;
    std::vector<double> CO_flow;
    std::vector<double> soot_flow;
    std::vector<double> time;
    for (int i(0); i < theMission->missionInfo.size(); i++) {
        CO2_flow.push_back(theMission->emissionFlow[i].CO2);
        H2O_flow.push_back(theMission->emissionFlow[i].H2O);
        SO2_flow.push_back(theMission->emissionFlow[i].SO2);
        SO4_flow.push_back(theMission->emissionFlow[i].SO4);
        NOx_flow.push_back(theMission->emissionFlow[i].NOx);
        HC_flow.push_back(theMission->emissionFlow[i].HC);
        CO_flow.push_back(theMission->emissionFlow[i].CO);
        soot_flow.push_back(theMission->emissionFlow[i].soot);
        time.push_back(theMission->missionInfo[i].time);
    }
    matplot::figure_handle fig = matplot::figure(true);
    matplot::axes_handle ax = fig->current_axes();
    matplot::hold(matplot::on);
    matplot::plot(time, CO2_flow);
    matplot::plot(time, NOx_flow);
    matplot::plot(time, H2O_flow);
    matplot::plot(time, soot_flow);
    matplot::plot(time, SO2_flow);
    matplot::plot(time, SO4_flow);
    matplot::plot(time, HC_flow);
    matplot::plot(time, CO_flow);
    matplot::hold(matplot::off);
    matplot::title("Emission Flow " + missionType + " Mission ");
    ax->xlabel("Time [s]");
    ax->ylabel("Emissions  [kg/s]");
    double y_max = std::max({*std::max_element(CO2_flow.begin(), CO2_flow.end()),
                            *std::max_element(NOx_flow.begin(), NOx_flow.end()),
                            *std::max_element(H2O_flow.begin(), H2O_flow.end()),
                            *std::max_element(soot_flow.begin(), soot_flow.end()),
                            *std::max_element(SO4_flow.begin(), SO4_flow.end()),
                            *std::max_element(SO2_flow.begin(), SO2_flow.end()),
                            *std::max_element(HC_flow.begin(), HC_flow.end()),
                            *std::max_element(CO_flow.begin(), CO_flow.end())});
    ax->ylim({ACCURACY_LOW, y_max*1.1+1}); // To get a plot if all emission are zero
    ax->y_axis().scale(matplot::axis_type::axis_scale::log);
    auto lgdEmissions = matplot::legend({"CO2", "NOx", "H2O", "Soot", "SO2", "SO4", "HC", "CO"});
    std::string plotFilePath = rtIO_->getPlotDir() + "/" + std::string(TOOL_NAME) + "_mission_" + missionType + ".svg";
    matplot::save(plotFilePath);
    matplot::cla();
}

