/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARACONFIG_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARACONFIG_H_

#include <string>
#include <aixml/endnode.h>
#include "../../emissionsClass.h"

/** \class DallaraConfig
 * \brief Class for the config settings needed for dallara strategy
*/
class DallaraConfig {
 public:
    //aigner: New Factors to account for variations in s_i_height
    //(Reference Dallara --> forcing factors (s_i_height) have a 66% likelihood range
    double s_i_heightVariation_AIC;/**< Variable for variation of AIC forcing factor [-]*/
    double s_i_heightVariation_O3S;/**< Variable for variation of O3S forcing factor [-]*/
    double s_i_heightVariation_CH4O3L;/**< Variable for variation of CH4O3L forcing factor [-]*/
    /*Climate effect input parameters*/
    double fuelAICfactor;/**<Factor to vary the impact of aircraft induced cloudiness (min: 0.3, max 0.8) [-]*/
    std::string s_i_dataSet;/**<Data set for forcing factor calculation. 'mode_0': Dallara 2011, 'mode_1': Dahlmann 2011*/
    int tmax;/**<Considered timeframe [yr] */
    double devRate;/**<Devaluation rate of the temperature response [-]*/
    int durationOperation; /**< Duration of the operating phase [yr] */

    /** \brief Default constructor of class DallaraConfig
     */
    DallaraConfig();

    /** \brief Destructor of class SchaeferIOData
     */
    virtual ~DallaraConfig();

    /** \brief Function to read schaefer specific data from ecological_assessment.xml
     * \param config node of the data structure defined by config file
     */
    void readAllConfigData(const node& config);

 private:
    /** \brief Function to read devlopment data from conig.xml
     * \param forcingFactor node of the forcingFactor in config file
     */
    void readForcingFactorConfigData(const node& forcingFactor);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARACONFIG_H_
