/* UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "../../standard_strategy.h"
#include "../../../toolinfo.h"
#include <vector>


void StandardStrategy::setHtmlBody_dallara(const std::shared_ptr<RuntimeIO> &rtIO) {// cppcheck-suppress unusedFunction
    /* Adjust the text part of the report: **/
    //table ATR
    report_->htmlReportStream()
       << html::h2("Climate Impact")
       << "<br>"
       << html::table_begin({"Parameter", "Comment", "Unit", "Value"}, "Climate metrics")
       << html::table_row("ATR", "<font size=\"-1\">Average Temperature Response per year for operating phase</font>", "10-2 mK",
                            Rounding(theClimateModelDallara.dallaraIOData_->ATR * 100000, 2))
       << html::table_row("AGTP", "<font size=\"-1\">Absolute Global Temperature Potential after final year of operation", "10-2 mK",
                            Rounding(theClimateModelDallara.TotalTempChangeTotal.at(theClimateModelDallara.dallaraIOData_->durationOperation) * 100000., 2))
       << html::table_row("AGTP100", "<font size=\"-1\">Absolute Global Temperature Potential after 100 years</font>", "10-2 mK",
                            Rounding(theClimateModelDallara.TotalTempChangeTotal.at(100) * 100000., 2))
       << html::table_row("AGWP", "<font size=\"-1\">Absolute Global Warming Potential after final year of operation</font>", "10<sup>-5</sup> W&sdot;yr/m<sup>2</sup>",
                            Rounding(theClimateModelDallara.absAGWPTotal.at(theClimateModelDallara.dallaraIOData_->durationOperation) * 100000., 2))
       << html::table_row("AGWP100", "<font size=\"-1\">Absolute Global Warming Potential after 100 years</font>", "10<sup>-5</sup> W&sdot;yr/m<sup>2</sup>",
                            Rounding(theClimateModelDallara.absAGWPTotal.at(100) * 100000., 2))
       << html::table_end;
       if (rtIO->plotOn) {
          report_->htmlReportStream()
              << html::image(relativePath(rtIO->getPlotDir() + FILESEPERATOR + std::string(TOOL_NAME) + "_climate_impact.svg", rtIO->getHtmlDir(), false), "");
       }
}

void StandardStrategy::setTexBody_dallara() {
    report_->texReportStream() << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl;
    report_->texReportStream() << "\\begin{frame}" << std::endl;
    report_->texReportStream() << "\\frametitle{Climate Impact}" << std::endl;
    report_->texReportStream() << "\\begin{table}" << std::endl;
    report_->texReportStream() << "     \\centering" << std::endl;
    report_->texReportStream() << "     \\scriptsize" << std::endl;
    report_->texReportStream() << "     \\begin{tabularx}{250pt}{Xrlr}" << std::endl;
    report_->texReportStream() << "         \\toprule" << std::endl;
    report_->texReportStream() << "             \\textcolor{ilrdark}{Parameter} & \\textcolor{ilrdark}{Comment} & \\textcolor{ilrdark}{Unit} & "
                                                 << "\\textcolor{ilrdark}{Value} \\\\" << std::endl;
    report_->texReportStream() << "             \\midrule[0.5pt]" << std::endl;
    report_->texReportStream() << "             ATR & \\tiny{Avg. Temp. Resp. per year for operating years} & $10^{-2} \\milli\\kelvin$ & "
                                                 << Rounding(theClimateModelDallara.dallaraIOData_->ATR * 100000, 2) << " \\\\"
                                                 << std::endl;
    report_->texReportStream() << "             AGTP & \\tiny{Abs. Global Warming Pot. after final year of operation} & $10^{-2} \\milli\\kelvin$ & "
                                                 << Rounding(theClimateModelDallara.TotalTempChangeTotal.at(theClimateModelDallara.dallaraIOData_->durationOperation)
                                                               * 100000., 2)
                                                 << " \\\\" << std::endl;
    report_->texReportStream() << "             AGTP100 & \\tiny{Abs. Global Warming Pot. after 100 years} &$10^{-2} \\milli\\kelvin$ & "
           << Rounding(theClimateModelDallara.TotalTempChangeTotal.at(100) * 100000., 2) << " \\\\" << std::endl;
    report_->texReportStream() << "             AGWP & \\tiny{Abs. Global Temp. Pot. after final year of operation} & $10^{-5} \\frac{\\watt ~\\yr}{\\square\\meter}$ & "
           << Rounding(theClimateModelDallara.absAGWPTotal.at(theClimateModelDallara.dallaraIOData_->durationOperation) * 100000., 2) << " \\\\" << std::endl;
    report_->texReportStream() << "             AGWP100 & \\tiny{Abs. Global Temp. Pot. after 100 years} & $10^{- 5} \\frac{\\watt ~\\yr}{\\square\\meter} $ & "
           << Rounding(theClimateModelDallara.absAGWPTotal.at(100) * 100000., 2) << " \\\\" << std::endl;
    report_->texReportStream() << "          \\bottomrule" << std::endl;
    report_->texReportStream() << "        \\end{tabularx}" << std::endl;
    report_->texReportStream() << "     \\end{table}" << std::endl;
    report_->texReportStream() << "\\end{frame}" << std::endl;
}
