/**
 * \file mission_analysis.h
 * \author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * \brief
 * \version 0.1
 * \date 2024-08-30
 *
 * @copyright Copyright (c) 2024
 *
 */
#ifndef MISSION_ANALYSIS_SRC_MISSION_ANALYSIS_H_
#define MISSION_ANALYSIS_SRC_MISSION_ANALYSIS_H_

#include <string>
#include <vector>
#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

class mission;

class mission_analysis : public Module {
 public:
    mission_analysis(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion);
    ~mission_analysis() = default;

    void initialize() override { missionStrategy_.initializeStrategy(); };
    void run() override { missionStrategy_.runStrategy(); };
    void update() override { missionStrategy_.updateStrategy(); };
    void report() override { missionStrategy_.reportStrategy(); };
    void save() override {
        missionStrategy_.saveStrategy();
        rtIO_->saveAcXML();
    };

 private:
    /** \brief Function check if the requirement mission has to be performed
     *  \return runRequirementCheck true if requirement mission has to be calculated
     *  \param mission_type: Identifier if it's a study or a design mession
     */
    bool has_requirements_to_be_checked(const std::string& mission_type);
    std::vector<std::string> route_;
    strategyaccess missionSelection_(const std::vector<std::string> &route);
    StrategySelector missionStrategy_;
};

#endif // MISSION_ANALYSIS_SRC_MISSION_ANALYSIS_H_
