/**
 * \file geometry_handling.cpp
 * \author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * \brief
 * \version 0.1
 * \date 2024-08-30
 *
 * @copyright Copyright (c) 2024
 *
 */
#include "../standard_mission/standard_mission.h"
#include <aircraftGeometry2/io/convert.h>

standard_mission::used_components::used_components()
    :
    /* Initialize the number of lifting surfaces with zero [dimensionless] */
    lifting_surfaces_quantity(0),
    /* Initialize the number of fuselages with zero [dimensionless] */
    fuselages_quantity(0) {
}

/* Destructor of used_components */
standard_mission::used_components::~used_components() {
}

void standard_mission::initialize_geometry() {
    /* Variable Chamber */
    this->variable_camber_switch = EndnodeReadOnly<bool>("requirements_and_specifications/design_specification/technology/variable_camber").read(rtIO->acxml).value();
    /* Get number of variable camber segments */
    if (this->variable_camber_switch) {
        std::string origin_polar_string = aero.getConfiguration(0).polars.at(0).vOrigin_polar.at(0);
        std::string string_tmp1 = origin_polar_string;
        this->variable_camber_segment_quantity = count(string_tmp1.begin(), string_tmp1.end(), '_');
    } else {
        this->variable_camber_segment_quantity = 0;
    }
    // TODO(Gerrit): No CG Shift -> geometry neglected
    /* Reading the geometry elements */
    /* read lifting surface elements from aircraft exchange file */
    // NEEEEEEEEEEEEEEEW //
    // std::vector<node*> liftingWingSurfaces = (rtIO->acxml).getVector("aircraft_exchange_file/component_design/wing/specific/geometry/aerodynamic_surface");
    // for (node* surfaceElement : liftingWingSurfaces) {
    //     usedElements.lifting_surfaces_vector.push_back(std::string(surfaceElement->at("name/value")));
    //     myRuntimeInfo->out << "Create: " << std::string(surfaceElement->at("name/value")) << " ..." << std::endl;
    //     //wing_surface_vector.push_back(geom2::MultisectionSurface<geom2::AirfoilSection>(rtIO->getIODir(), *surfaceElement, surfaceElement->at("name/value")));
    // }

    // std::vector<node*> liftingEmpennageSurfaces = (rtIO->acxml).getVector("aircraft_exchange_file/component_design/empennage/specific/geometry/aerodynamic_surface");
    // for (node* surfaceElement : liftingEmpennageSurfaces) {
    //     usedElements.lifting_surfaces_vector.push_back(std::string(surfaceElement->at("name/value")));
    //     myRuntimeInfo->out << "Create: " << std::string(surfaceElement->at("name/value")) << " ..." << std::endl;
    //     horizontal_tail_surface_vector.push_back(geom2::MultisectionSurface<geom2::AirfoilSection>(rtIO->getIODir(), *surfaceElement, surfaceElement->at("name/value")));
    // }
    // usedElements.lifting_surfaces_quantity = liftingWingSurfaces.size() + liftingEmpennageSurfaces.size();

    // /* Check if fuselage has a lifting surface */
    // if ((rtIO->acxml).find("aircraft_exchange_file/component_design/fuselage/specific/geometry/aerodynamic_surface")) {
    //     std::vector<node*> liftingFuselageSurfaces = (rtIO->acxml).getVector("aircraft_exchange_file/component_design/fuselage/specific/geometry/aerodynamic_surface");
    //     for (node* surface : liftingFuselageSurfaces) {
    //         usedElements.lifting_surfaces_vector.push_back(std::string(surface->at("name/value")));
    //         myRuntimeInfo->out << "Create: " << std::string(surface->at("name/value")) << " ..." << std::endl;
    //         }
    //     usedElements.lifting_surfaces_quantity += liftingFuselageSurfaces.size();
    // }
    // /* read fuselage elements from aircraft exchange file */
    // std::vector<node*> fuselageElements = rtIO->acxml.getVector("aircraft_exchange_file/component_design/fuselage/specific/geometry/fuselage");
    // usedElements.fuselages_quantity= fuselageElements.size();
    // for (node* fuselageElement : fuselageElements) {
    //     usedElements.lifting_fuselage_vector.push_back(std::string(fuselageElement->at("name/value")));
    //     myRuntimeInfo->out << "Create: " << std::string(fuselageElement->at("name/value")) << " ..." << std::endl;
    //     // fuselage_vector.push_back(fuselage(rtIO->getIODir(), *fuselageElement, std::string(fuselageElement->at("name/value"))));
    // }
    // usedElements.fuselages_quantity= fuselageElements.size();
    //////////////////////////////////////////
    /* Reading the geometry elements */
    /* read lifting surface elements from aircraft exchange file and check given boundary condition [dimensionless] */
    // OOOOOOOOOOOOOOOOOLD
//     usedElements.lifting_surfaces_quantity    = checkBoundaries(oldXML.at("AcftExchangeFile/Geometry/UsedElements/LiftingSurfaces"), 1, true, 3, true);
//     /* read fuselage elements from aircraft exchange file and check given boundary condition [dimensionless] */
//     usedElements.fuselages_quantity         = checkBoundaries(oldXML.at("AcftExchangeFile/Geometry/UsedElements/Fuselages"), 0, true, 2, true);
//     /* Loop across all lifting surface elements to read and create each of them */
//     for (uint8_t i(0); i < usedElements.lifting_surfaces_quantity; ++i) {
//         usedElements.lifting_surfaces_vector.push_back(std::string(oldXML.at("AcftExchangeFile/Geometry/UsedElements/LiftingSurface@" + num2Str(i + 1))));
//         myRuntimeInfo->out << "Create: " << usedElements.lifting_surfaces_vector.at(i) << " ..." << std::endl;
//         /* Check if loop counter == 0  -> if true: -> current lifting surface is the wing -> push to wing geometry elements */
//         if (i == 0) {
//             wing_surface_vector.push_back(geom2::MultisectionSurface<geom2::AirfoilSection>(rtIO->getIODir() + "/",
//                                               oldXML.at("Geometry/LiftingSurface@" + usedElements.lifting_surfaces_vector.at(i)), usedElements.lifting_surfaces_vector.at(i)));
//         /* Else condition: current lifting surface is the horizontal tail plane -> push to horizontal tail plane geometry elements */
//         } else {
//             this->horizontal_tail_surface_vector.push_back(geom2::MultisectionSurface<geom2::AirfoilSection>(rtIO->getIODir() + "/", oldXML.at("Geometry/LiftingSurface@" + usedElements.lifting_surfaces_vector.at(i)),
//                                         this->usedElements.lifting_surfaces_vector.at(i)));
//         }
//     }
//     /* Loop across all fuselage elements to create and push to fuselage geometry elements */
//     for (uint8_t i(0); i < this->usedElements.fuselages_quantity; ++i) {
//         this->usedElements.lifting_fuselage_vector.push_back(std::string(oldXML.at("AcftExchangeFile/Geometry/UsedElements/Fuselage@" + num2Str(i + 1))));
//         myRuntimeInfo->out << "Create: " << this->usedElements.lifting_fuselage_vector.at(i) << " ..." << std::endl;
//         this->fuselage_vector.push_back(fuselage(rtIO->getIODir() + "/", oldXML.at("Geometry/Fuselage@" +
//                                         this->usedElements.lifting_fuselage_vector.at(i)), this->usedElements.lifting_fuselage_vector.at(i)));
//     }
//     ///////////////////////////////////////

//     std::filesystem::path fuselage_path(rtIO->getGeometryDir());
//     std::filesystem::path wing_path(rtIO->getAirfoilDataDir());
//     // std::filesystem::path acxmlpath("../../rAIRCRAFTREFERENCES/csmr-2020.xml");
//     std::filesystem::path acxmlpath(rtIO->acxmlAccess);
//     std::shared_ptr<node> acxml(aixml::openDocument(acxmlpath));
//     geom2::FuselageFactory fuselageFactory{acxml, fuselage_path};
//     geom2::WingFactory wingFactory{acxml, wing_path};
//     geom2::MultisectionSurface<geom2::PolygonSection> fuselage = fuselageFactory.create("fuselage/specific/geometry/fuselage@0");
//     geom2::MultisectionSurface<geom2::AirfoilSection> wing = wingFactory.create("wing/specific/geometry/aerodynamic_surface@0");
//     // double bla = geom2::measure::mean_aerodynamic_chord(wing);

//     // myRuntimeInfo->out << fuselage_vector.at(0).getLocalWidth(this->wing_surface_vector.at(0).referencePtx) / 2.0 << std::endl;
//     // myRuntimeInfo->out << this->wing_surface_vector.at(0).RightWing.back().segReference[1] << std::endl;
//     // myRuntimeInfo->out << bla << std::endl;

//     ////// LIB
//     node& wing_ref(rtIO->acxml.at("component_design/wing/position"));
//     /* getLocalWidth */
//     myRuntimeInfo->out << "a1: " << fuselage_vector.at(0).getLocalWidth(this->wing_surface_vector.at(0).referencePtx) / 2.0 << std::endl;
//     // =
//     myRuntimeInfo->out << "a2: " << geom2::measure::width(fuselage, EndnodeReadOnly<double>("x").read(wing_ref).value()) / 2.0 << std::endl;
//     /* aero chord */
//     // myRuntimeInfo->out << "b1: " << this->wing_surface_vector.at(0).RightWing.back().segReference[1] - this->wing_surface_vector.at(0).referencePty << std::endl;
//     // =
//     myRuntimeInfo->out << "b2: " << geom2::measure::volume(wing) << std::endl;
//     //////

// ///TEST///
//     double fuel_cg(0.), right_side_fuel_cg(0.), left_side_fuel_cg(0.), nominator_cg_right_wing(0.);
//     double right_side_tank_volume(0.), left_side_tank_volume(0.), step_length(0.), max_half_span_width(0.), fuselage_radius(0.), wing_tank_fuel_volume(0.);
//     uint8_t number_of_steps(25);
//     wing_tank_fuel_volume += EndnodeReadOnly<double>("component_design/tank/specific/tank@0/energy").read(rtIO->acxml).value() / KEROSENE_VOLUMETRIC_ENERGY_DENSITY;
//     wing_tank_fuel_volume += EndnodeReadOnly<double>("component_design/tank/specific/tank@1/energy").read(rtIO->acxml).value() / KEROSENE_VOLUMETRIC_ENERGY_DENSITY;
//     myRuntimeInfo->out << wing_tank_fuel_volume << std::endl;
//     max_half_span_width = this->wing_surface_vector.at(0).RightWing.back().segReference[1] - this->wing_surface_vector.at(0).referencePty;
//     fuselage_radius = fuselage_vector.at(0).getLocalWidth(this->wing_surface_vector.at(0).referencePtx) / 2.0;
//     step_length = (max_half_span_width - fuselage_radius) / number_of_steps;
//     for (uint8_t steps(0); steps < number_of_steps - 1; ++steps) {
//         /* Right lifting surface tank, starting at fuselage lifting surface junction */
//         double left_y_position = fuselage_radius + steps * step_length;
//         double base_area = this->wing_surface_vector.at(0).getAreaBetweenSpars(left_y_position, skin_thickness, "right");
//         double area_at_middle_height = this->wing_surface_vector.at(0).getAreaBetweenSpars(left_y_position + 0.5 * step_length, skin_thickness, "right");
//         double top_area = this->wing_surface_vector.at(0).getAreaBetweenSpars(left_y_position + step_length, skin_thickness, "right");
//         /* Determine incremental tank volume using prismatoid equation */
//         double incremental_tank_volume(step_length * (base_area + 4. * area_at_middle_height + top_area) / 6.);
//         right_side_tank_volume += incremental_tank_volume;
//         /* Determine local ref position position (quarter chord point) at half of incremental part */
//         Vec3 local_ref_point(this->wing_surface_vector.at(0).getLocalRefPoint(left_y_position + 0.5 * step_length, "right"));
//         Vec3 local_cg_point(local_ref_point);
//         /* Determine x coordinate in more detail, using rel. x CoG position of wing tank referenced to quarter chord */
//         double deltaXLocal25toCoG = 0.5 * (this->wing_surface_vector.at(0).getLocalFrontSparPosition(local_ref_point[1], "right")
//                                             + this->wing_surface_vector.at(0).getLocalRearSparPosition(local_ref_point[1], "right")) - 0.25;
//         deltaXLocal25toCoG *= this->wing_surface_vector.at(0).getLocalChord(local_ref_point[1], "right");
//         local_cg_point[0] = local_ref_point[0] + deltaXLocal25toCoG;
//         /* Calculate nominator for center of gravity */
//         nominator_cg_right_wing += incremental_tank_volume * local_cg_point[0];
//         /* Symmetry is assumed */
//         left_side_tank_volume = right_side_tank_volume;
//         /* Stop if Tankvolume gets bigger than the values in Ac.xml */
//         if (convertUnit(VOLUME, NOPREFIX, METER, NOPREFIX, LITER, right_side_tank_volume) +
//             convertUnit(VOLUME, NOPREFIX, METER, NOPREFIX, LITER, left_side_tank_volume) >= wing_tank_fuel_volume) {
//             break;
//         }
//     }
/////////



    /* Loop through tanks and known tank types to allocate the corresponding volume */
    for (node* tankElement : (rtIO->acxml.at("component_design/tank/specific")).getVector("tank")) {
        for (uint8_t i(0); i < this->centerTankTypes.size(); i++) {
            if (std::string(tankElement->at("name/value")) == this->centerTankTypes[i]) {
                this->fuel_volume_center_tanks += static_cast<double>(tankElement->at("volume/value"));
            }
        }
        for (uint8_t i(0); i < wingTankTypes.size(); i++) {
            if (std::string(tankElement->at("name/value")) == this->wingTankTypes[i]) {
                this->fuel_volume_wing_tanks += static_cast<double>(tankElement->at("volume/value"));
            }
        }
    }

     /* read CoG x-position of wing from aircraft exchange file and check given boundary condition [m] */
    // this->cg_wing = 17.1682343; //TODO(Gerrit) hier: fuselage_vector.at(0).l, true);

    /* Tank Error catch */
    // if (this->number_center_tanks == 0 && this->number_trim_tanks == 0 && this->number_wing_tanks == 0) {
    //    throwError(__FILE__, __func__, __LINE__, "No tanks could ne identified: Please check the tank description and/or the name!");
    // }
}
