/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef PERFORMANCE_ASSESSMENT_SRC_PERFORMANCE_ASSESSMENT_H_
#define PERFORMANCE_ASSESSMENT_SRC_PERFORMANCE_ASSESSMENT_H_

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>

#include <string>
#include <vector>

/**
 * \brief performance_assessment module for calculating the performance of your Kfz
 * 
 */
class performance_assessment : public Module {
 public:
        performance_assessment(const int argc, char *argv[], const std::string& toolName, const std::string& toolVersion);
        ~performance_assessment() = default;

        void initialize() override { strategy.initializeStrategy(); };
        void run() override { strategy.runStrategy(); };
        void update() override { strategy.updateStrategy(); };
        void report() override{ strategy.reportStrategy(); };
        void save() override {
            strategy.saveStrategy();
            aixml::saveDocument(rtIO_->acxml);
        };

        std::vector<std::string> route;
        strategyaccess design_routing(const std::vector<std::string> &route);
        StrategySelector strategy;
};

#endif  // PERFORMANCE_ASSESSMENT_SRC_PERFORMANCE_ASSESSMENT_H_
