# Implemented Aircraft System Models

\anchor ATA21-ECS
## ATA 21: Environmental Control System
The environmental control system model implemented is powered by electric power and bleed air from the engines.

**Methods**

The power required by the environmental control system is calculated based on the heat loads of all systems, the heat from the sun and from the passengers. The ECO-Mode allows to reduce the required bleed air by 25%. Air conditioning is switched off during takeoff.

The mass of the ECS depends on the bleed air mass flow in the design point. Calculation method from LTH and Howe. The mass is broken down into the components ducts, air conditioning pack, outlet, ram inlet, vents, and misc. according to factors determined by Koeppen.

The CoG of the ECS is determined with the assumption that its located in the belly fairing.

**Required Input Parameters**

* Airflow per PAX [kg/s]
* Recirculation [-]: percentage of cabin air that is reused (0.0 - 1.0)
* Heat Convection [W/(m^2*K)]: heat convection over aircraft skin (based on Airbus air conditioning system design)
* Cabin Temperature [K]
* Specific Heat Flow from Sun [W/m^2]
* Window Area [m^2]: Area of a single window
* Heat per PAX [W]: heat emitted per person
* Heat per Light Length [W/m]
* Efficiency Factor of the Air Conditioning Pack [-]
* Heat Capacity Air [J/(kg*K)]
* Off Take Off: Switch to turn of ACP during take off
* ECO Mode: Switch for ECO Mode reduces bleed air requirement by 25%

\anchor ATA24-electric
## ATA 24: Electric System

**Methods**

`CheckUserInput()` checks if generator sources exist.

The required power of the electric system is the power lost through inefficiencies. The efficiency factor for the electric system and for the generators are considered.

The mass calculation method from Steinke is based on the maximum required electric power and the cable length. The cable length is defined as 2*fuselage length (main bus from front to back, two bus systems) + connection of the engines to the avionics bay. A factor is applied to the mass depending on the design range of the aircraft (short or long range).

**Required Input Parameters**

* Efficiency Factor [-]
* Maximum Relative Power [-]: ratio of maximum permanent power and maximum required power of all generators
* Specific Cable Mass [kg/m]
* Number of Electric Circuits [-]
* Number of Generators [-]
* For each Generator:
    * name
    * type (IDG, APUG, ...)
    * source type (hydraulic, engine, APU)
    * source ID
    * efficiency
    * operation factor (share of total power in normal operation)

\anchor ATA25-furnishing
## ATA 25: Furnishing System

Furnishing system includes the power required for the galleys and the inflight entertainment system (IFE). The mass of all furnishing is calculated in fuselage design and read from the aircraft exchange file.

**Methods**

Power calculation is done based on user inputs.

**Required Input Parameters**

* Galley Load Fraction during Takeoff [-]:
    Electric Load Analysis for A320 suggest a value of 0.2 [[1]](\ref additional_sources)
* Galley Load Fraction during Cruise [-]:
    Electric Load Analysis for A320 suggest a value of 0.7 [[1]](\ref additional_sources)
* Galley Load Fraction during Descent [-]:
    Electric Load Analysis for A320 suggest a value of 0.2 [[1]](\ref additional_sources)
* Galley Location [m]
* Non Personal IFE Power [W]: General power for IFE
* Personal IFE Power [W]: Power for IFE per PAX
* Personal IFE Load Fraction Climb [-]:
    Electric Load Analysis for A320 suggest a value of 0.58 [[1]](\ref additional_sources)
* Personal IFE Load Fraction Cruise [-]:
    Electric Load Analysis for A320 suggest a value of 1 [[1]](\ref additional_sources)
* Personal IFE Load Fraction Descent [-]:
    Electric Load Analysis for A320 suggest a value of 0.5 [[1]](\ref additional_sources)

\anchor ATA26-fire
## ATA 26: Fire Protectrion System

Does not require power!

**Methods**

Mass calculation is based on propulsion type and MTOM (Torenbeek Tab. 8-12).

**Required Input Parameters**

None.

\anchor ATA27-flight-control
## ATA 27: Flight Control System

The flight control system is modeled in great detail down to the individual actuators of the control surfaces. The calculation is devided into segments according to the control surfaces:

* Ailerons
* Spoilers
* Elevators
* Rudders
* Trimmable Horizontal Stabilizers (THSAs)
* Flaps
* Slats

The actuator architecture is defined by the user in the configuration file but the control surface geometry is read from the aircraft exchange file. The control surface geometry from the aircraft exchange file and the actuator architecture are checked against each other to make sure they match.

**Methods**

The function `setHorizontalContrSurfGeo` is used to read the geometry of horizontal control surfaces (e.g. ailerons, elevator) while the function `setRudderTemp` is used for the rudder. For the THSA there is a specialized function to read the geometry: `setTHSA_AsControlSurface`. These functions are used to calculate the area moment about the hinge line of each control surface and to determine the reference points of the actuators. This requires the geometry of the aerodynamic surface the control surfaces is mounted on and the geometry of the control surface itself, as well as the maximum deflection, deflection speed and number of actuators on the control surface.

The design power of primary flight control surfaces is calculated based on the control surface geometry and hinge moment, the wing loading, and the maximum operating speed of the aircraft. The hinge moment is determined according to [NASA76] (equations on page 26).

For the high lift system there's a separate class calculating the mass and power required (`class highLiftSystem`). This class and all other classes used for the calculation of the high lift system are in the folder src/aircraftSystems/highLiftSystem. The high lift devices are sorted into trailing edge and leading edge panels. For each device the actuation moments for the actuators, their work load and power are calculated. The mass consists of the masses of the actuation and support, the PCU, the wing tip brakes, the gear boxes, the torque shaft, and the torque limiters. The power consists of the actuation power and PCU power.

There are two functions for the mission power allowing for detailed power calculation at each mission step or the calculation of the average mission power. Power calculation is the same as for the design power but with the flight speed at the given mission step.

The mass of the primary flight control system is based on [NASA76, p. 42-48].

**Required Input Parameters**

There are some general inputs and then inputs for each control surface type. The general inputs are:

* Switch whether loads for each mission step are calculated (otherwise average values)
* Switch for electrical flight control system
* Common installation weight factor [-]
* Default actuator:
    * Power Source (type and ID)
    * Operation Mode (active, standby or damping during normal operation)
    * Efficiency [-]
    * Standby Power [W]
    * Active Power [W]

Specific inputs for each control surface type:

* Weight Factor for Electric Flight Control System [-]
  (This factor will only be applied if the switch for electric flight control system is set true!)
* Switch if default actuator architecture should be used
* Default Actuator Architecture:
    * Number of Actuators per Control Surface [-]
    * Default Deflection Speed [deg/s]
* Manual Acturator Archtitecture:
    * Number of Control Surfaces [-]
    * For each Control Surface:
        * Side (left or right)
        * Deflection Speed [deg/s]
        * Actuator Layout:
            * Number of Actuators [-]
            * For each actuator same parameters as for default actuator

Acceptable control surface names are:

* ailern / droop_aileron
* spoiler_air / spoiler_ground
* flap / slotted_flap / ADHF / fowler / double_fowler / triple_fowler / special / morphing_trailing_edge
* slat / krueger / droop_nose / morphing_droop_nose / special

**Note**: not all of these devices are implemented. If they aren't implemented a default will be used and a warning issued.

\anchor ATA28-fuel
## ATA 28: Fuel System

**The fuel system does not contain the tank mass!**

**Methods**

The power of the electric powered pumps of the fuel system is calculated according to Buente, based on the MTOM.

The mass of the fuel system is the mean value of the results from the Raymer and Torenbeek method. A technology factor of 0.7 is applied to the Raymer method.

The CoG is assumed to be the same as that of the wing.

**Required Input Parameters**

None

\anchor ATA29-hydraulic
## ATA 29: Hydraulic System

**Methods**

`CheckUserInput()` checks if pump sources exist.

The required power of the hydraulic system is the power lost through inefficiencies. The efficiency factor for the hydraulic system and for the pumps are considered.

The mass calculation method from [Steinke](\ref additional_sources) is based on the maximum required hydraulic power, the OME, the fluid mass and the ducting length. The ducting length is composed of the lengths from the engines to the belly fairing, the front gear to the back gear, 2 * the length of the wing trailing edge, 2 * the trailing edges of the horizontal and vertical tail plane. The total length is then doubled to account for the backflow.

**Required Input Parameters**

* Pressure [Pa]
* Efficiency Factor [-]
* Relative Maximum Power [-]: Ratio of maximum permanent power and maximum required power of all pumps
* Specific Ducting Mass [kg/m]
* Specific Pump Mass [kg/W]
* Number of Hydraulic Circuits [-]
* For each circuit:
    * Compartment Reference Point [m]
    * Number of Pumps [-]
    * For each pump:
        * Name
        * Type (electric driven, enginge driven, RAT)
        * Pump Efficiency [-]
        * Operation Factor [-]: Percentage of total pump power in normal operation
        * Power Source (type and ID)

## ATA 30: Ice and Rain Protection System

There are two implemented models for the ice and rain protection system - a conventional one powered by bleed air and an electric one.

\anchor ATA30-ice-conventional
### Conventional ATA 30

**Methods**

Mass is calculated as a percentage of the OME defined by the user.

Anti-Icing is typically applied from the kink of the wing and ends at the outer most leading edge device. If there are no leading edge devices the anti-icing is applied up until the wing tip. The icing conditions are then calculated based on the design altitude and design mach number. If there are icing conditions the external heat flux is calculated based on the water catch, the external heat transfer coefficient, the vapour pressure and from that the skin temperature. The required bleed air mass flow can then be calculated with the external heat flux, the inner skin temperature, the bleed air temperature and the bleed air efficiency.

**Required Input Parameters**

* Switch to turn off anti-icing
* Top Operating Altitude [m]
* Engine Anti Ice Bleed Air Mass Flow [kg/s]
* Skin Thickness [m]
* Relative Half Span Width to Start Anti-Icing [-]
* Heat Conductivity Wing [W/(m*K)]
* Drop Diameter [micro meter]
* Mass Percentage of OME [-]

\anchor ATA30-ice-electric
### Electric ATA 30

Mass is calculated as a percentage of the OME defined by the user.

**Methods**

Same calculation for the external heat flux. From there the required electric power can be calculated with the electro thermic efficiency and the user defined electric power.

**Required Input Parameters**

Same as for conventional +

* Electric Power Consumption Departure [W]:
    Electric Load Analysis for A320 suggest a value of 14026.9 W [[1]](\ref additional_sources)
* Electric Power Consumption Cruise [W]:
    Electric Load Analysis for A320 suggest a value of 13070.9 W [[1]](\ref additional_sources)
* Electric Power Consumption Approach [W]:
    Electric Load Analysis for A320 suggest a value of 14026.9 W [[1]](\ref additional_sources)
* Electric Power Consumption Land [W]
    Electric Load Analysis for A320 suggest a value of 7192.9 W [[1]](\ref additional_sources)
* Efficiency Electro Thermic Anti-Icing [-]

\anchor ATA32-gear
## ATA 32: Landing Gear System

**Methods**

Mass based on MLM. **Important:** it needs to be checked if this is actually the landing gear actuation mass or the mass of the gear!

The retraction and extension power are calculated based on the mass of the landing gear (read from aircraft exchange file), the strut length of the main gear, and the retraction/extension time.

**Required Input Parameters**

* Efficiency Factor [-]
* Retraction Time [s]
* Extension Time [s]
* Power Source(s)

\anchor ATA33-lighting
## ATA 33: Lighting System

**Methods**

Mass calculation is based on MTOM [Sch04].

Info:

* A320 Landing Lights weights according to honeywell = 2 * 7.484kg
* A320 LED Navigation Lights Goodrich Lighting Systems (green/red) = 2 * 0.408kg
* A320 Logo Lights weights according to honeywell = 2 * 1.4kg

CoG assumed at 45% fuselage length.

The design electric power is calculated assuming all lights are on. For the mission power only the lights on in the respective mission steps are considered. Same for the heat load.

**Required Input Parameters**

* Navigation Light Power [W]
* Rotating Beacon Light Power [W]
* Wing Light Power [W]
* Runway turn-off Light Power [W]
* Taxi Light Power [W]
* Landing Light Power [W]
* Logo Light Power [W]
* Strobe Light Power [W]
* Specific Emergency Light Power [W/m^3]
    Electric Load Analysis for A320 suggest a value of 1.46 W/m^3 [[1]](\ref additional_sources)
* Specific Cabin Light Power [W/m^3]
    Electric Load Analysis for A320 suggest a value of 18.04 W/m^3 [[1]](\ref additional_sources)
* Flight Deck Light Power [W]
    Electric Load Analysis for A320 suggest a value of 904.4 W [[1]](\ref additional_sources)
* Power Sources

\anchor ATA35-oxygen
## ATA 35: Oxygen System

The oxygen system does not require power.

**Methods**

The mass is calculated according to Torenbeek based on the number of PAX and depending on the design range of the aircraft.

**Required Input Parameters**

None.

\anchor ATA36-bleed
## ATA 36: Bleed Air System

**Methods**

Mass results from ducting mass. The length of the ducts consists of the connectioin from the wing to the APU and the wing to the engines.

CoG assumes the bleed air system is located in the belly fairing.

Bleed air required by the bleed air system is based on the efficiency losses in the system. The heat load is calculated by converting the efficiency losses to heat.

**Required Input Parameters**

* Bleed Air Temperature [C]
* Efficiency Factor [-]
* Specific Ducting Mass [kg/m]

\anchor ATA49-APU
## ATA 49: Auxiliary Power Unit (APU)

The APU is the only power source sized within systems design. However, it is only operated on ground. Ground operations are not included in the mission analysis in UNICADO, thus, the kerosene required by the APU is neglected.

**Methods**

The APU mass is calculated based on its design power (bleed air is converted to [W] via the thermal efficiency) and considering the installation factor. The equation is a regression based on LTH data, developed by F. Peter.

The power provided by the APU is calculated with the user defined percentages and efficiencies multiplied with the total required power of all systems.

**Required Input Parameters**

* Position of the APU relative to the fuselage length [-]
* Percentage of bleed air generated by the APU [-]
* Percentage of electric power generated by the APU [-]
* Percentage of hydraulic power generated by the APU [-]
* Bleed air efficiency factor [-]
* Installation factor for attached parts such as fire protection, noise protection, etc. [-]
* Percentages of power provided by APU for design case (bleed air, electric power, hydraulic power) [-]

\anchor ATA70-engine
## ATA 70: Engine

This model is only used to account for power extraction efficiencies of the engine. The engine is sized in the engine design module. The powere required by the systems from the engine is checked against the maximum power the engine can provide before updating the xml files. If at power peaks more power is required than available the less power over a longer amount of time will be written to the xml.

**Methods**

The efficiency factors for the shaft power extraction (electric + hydraulic power) are those defined for the generators and pumps.

**Required Input Parameters**

* Percentage of bleed air provided by the engine [-]
* Percentage of electric power provided by the engine [-]
* Percentage of hydraulic power provided by the engine [-]
* Efficiency factor for the bleed air extraction [-]

\anchor ATAXX-remaining
## ATA XX: Remaining Consumers

The remaining consumers are the avionics and their power requirement is derived as a percentage of the power required by all other sink systems.

**Methods**

Power: Percentage * Power of previous systems.

The mass is calculated according to Torenbeek p. 289. The method requires the maximum range, however that is not known yet by UNICADO at this point. Thus, the design range is used. The mass also depends on the OME and is multiplied by the user defined scaling factor.

The CoG is calculated assuming the instruments are placed at the end of the cockpit segment and tthe auto flight system, navigation and communication are placed in the avionics bay located either in the nose for business jet-like AC or behind the cockpit segment for all other aircraft (this is defined by the user in the configuration file).

**Required Input Parameters**

* Location of the avionics bay (wing root, nose, behind cockpit)
* Percentages of unrecorded power (bleed air, electric and hydraulic power) [-]
* Scaling factor [-]
* Mass percentage of ATA XX for instrumentation [-]
* Mass percentage of ATA XX for auto flight [-]
* Mass percentage of ATA XX for navigation [-]
* Mass percentage of ATA XX for communication [-]

\anchor additional_sources
### Additional Sources
[1] Source documents are available in German and can be requested from the RWTH Aachen.