/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_TRANSMISSIONSHAFT_H_
#define SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_TRANSMISSIONSHAFT_H_

#include <string>

/** \brief contains all properties of the transmission shaft
 */
class TransmissionShaft {
 public:
    double Mass;/**< [kg] mass of the transmission shaft */
    double efficiencyFactor;/**< [-] efficiency factor of the transmission shaft */
    double rotationSpeedShaft;/**< [1/s] rotation speed of the transmission shaft */

    /** \brief calculates the transmission shaft mass
     *
     * \param deviceType string
     * \param wingSpan double: [m]
     * \return void
     *
     */
    void getMass(const std::string& deviceType, double wingSpan);

    explicit TransmissionShaft(const std::string& Type);
    virtual ~TransmissionShaft();
};

#endif // SYSTEMS_DESIGN_SRC_AIRCRAFTSYSTEMS_HIGHLIFTSYSTEM_TRANSMISSIONSHAFT_H_
