/*  Copyright (C) 2011-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "theTorqueLimiters.h"

#include <runtimeInfo/runtimeInfo.h>

theTorqueLimiters::theTorqueLimiters(const std::string& Type)
    :
    Mass(0.0) {
    if (Type == "Slat") {
        efficiencyFactor = 1.0;
    } else if (Type == "Fowler") {
        efficiencyFactor = 1.0;
    } else {
        myRuntimeInfo->err << "The system type \"" << Type << "\" is unknown. No torque limiter can be created!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
    //ctor
}

theTorqueLimiters::~theTorqueLimiters() {
    //dtor
}

void theTorqueLimiters::getMass(const std::string& deviceType, double totalActuationMass) {
//NOTE (aigner#1#): 0.5925 ist LE Anteil Actuation Mass s. [Cha10] S. 67 Usprung Thielecke ...
//0.695 ist TE Anteil Actuation Mass s. [Cha10] S. 67 Usprung Thielecke
//Methode aus s. [Cha10] S. 67 Usprung
//Faktoren geaendert von Lammering in rev2131 im Maerz 2013
    if (deviceType == "Slat") {
        Mass = 0.15 * totalActuationMass / 0.5925;
    } else if (deviceType == "Fowler") {
        Mass = 0.125 * totalActuationMass / 0.695;
    } else {
        myRuntimeInfo->err << "The system type \"" << deviceType << "\" is unknown. Mass cannot be calculated!" << std::endl;
        myRuntimeInfo->err << "Abort!" << std::endl;
        exit(1);
    }
}
