/**
 * \file standardReport.cpp
 * \author 
 * \brief standard systems design report implementation (html and tex)
 * \version 0.1
 * \date 2024-06-27
 * 
 * @copyright Copyright (c) 2024
 * 
 */
#include "standardSystemsDesign.h"
#include "toolinfo.h"
#include <vector>

void standardSystemsDesign::setHtmlBody() {
      /* Add box data */
      report_.htmlReportStream() << "<div class=\"box data\">\n";
      /* Add headline Data*/
      report_.htmlReportStream() << "<caption>Program Mode: </caption>";
      if (data_->configuration.designCase == true) {
         report_.htmlReportStream() << "Sizing Mode" << std::endl;
      } else {
         report_.htmlReportStream() << "Analysis Mode" << std::endl;
      }
/* Mass Breakdown Section */
      /* Add headline */
      report_.htmlReportStream() << "<h2>Mass Breakdown</h2>" << std::endl;
      if (data_->configuration.designCase == true) {
         report_.htmlReportStream() << "<div id=\"leftCol\">" << std::endl
         //Table:
                                    << "<table class=\"content-table\">\n" << std::endl
                                    << "<caption> Aircraft Mass Breakdown </caption>\n"
                                    << "<tr>" << std::endl
                                    << std::setprecision(5) << "<td>OME</td><td>" << data_->data.Mass.OME << " kg</td><td>"
                                    << "(Previous OME: " << data_->PreviousOME << " kg)" << "</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>MME</td><td>" << data_->data.Mass.MME << " kg</td><td>" "(Previous MME: " << data_->PreviousMME << " kg)" << "</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>+</td><td>Structures</td><td>" << data_->data.Mass.Structure <<
                                       " kg</td><td>(Fuselage, Wing, Empennage, Landing Gear, Pylons)</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>+</td><td>Power Unit</td><td>" << data_->data.Mass.totalGroupAllEngines <<
                                       " kg</td><td>(including Bleed Air System & Fuel System)</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>+</td><td>Systems Group</td><td>" << data_->data.Mass.systemsGroup << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>+</td><td>Furnishings Group</td><td>" << data_->data.Mass.furnishingsGroup << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>+</td><td>not Allocated</td><td>" << data_->data.Mass.notAllocatedSystems << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "</table>" << std::endl
                                    << "</div>" << std::endl
                                    << "<div id=\"rightCol\">" << std::endl
         //Graphic:
                                    << "<img class=\"image-plot\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                       "_MassBreakdown_plot.svg\">" << std::endl
                                    << "</div>" << std::endl;
      } else {
         report_.htmlReportStream() << "<td>The program was run in analysis mode.</td>" << std::endl
                                    << "<td>The masses were not redetermined!</td>" << std::endl;
      }
      report_.htmlReportStream() << "<h2>Systems Masses</h2>" << std::endl;
      if (data_->configuration.designCase == true) {
         report_.htmlReportStream() << "<div id=\"leftCol\">" << std::endl
                                    << "<table>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td><h3>Systems Group</h3></td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    if (data_->Systems.systemExists("ATA-21")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-21</td><td>Air Conditioning</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-21"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-24")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-24</td><td>Electric System</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-24"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-26")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-26</td><td>Fire Protection</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-26"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-27")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-27</td><td>Flight Control</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-27"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-29")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-29</td><td>Hydraulic System</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-29"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-30")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-30</td><td>Anti-Icing</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-30"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-XX")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-XX</td><td>Remaining Consumers (including Avionics)</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-XX"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>ATA-49</td><td>APU</td><td>";
                                    }
                                    if (data_->Systems.systemExists("ATA-49")) {
                                    report_.htmlReportStream() << std::setprecision(4)
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-49"))->Mass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
         report_.htmlReportStream()<< "<td><h2>Power Unit Group</h2></td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    if (data_->Systems.systemExists("ATA-28")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-28</td><td>Fuel System</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-28"))->Mass << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-36")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-36</td><td>Bleed Air</td><td>"
                                    << data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-36"))->Mass << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    report_.htmlReportStream() << "<td><h2>Furnishing Group</h2></td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    if (data_->Systems.systemExists("ATA-25")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-25</td><td>Furnishing</td><td>" <<
                                       data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-25"))->Mass << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-33")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-33</td><td>Lighting</td><td>" <<
                                       data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-33"))->Mass << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-35")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-35</td><td>Oxygen</td><td>" <<
                                       data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-35"))->Mass << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    if (data_->Systems.systemExists("ATA-38")) {
                                    report_.htmlReportStream() << std::setprecision(4) << "<td>ATA-38</td><td>Water & Waste</td><td>" <<
                                       data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-38"))->Mass << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl;
                                    }
                                    report_.htmlReportStream() << "<td><h2>Operator Items</h2></td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>---</td><td>Op. items calc. in systemsDesign (liquid)</td><td>"
                                    << data_->data.Mass.waterAndChemicalsMass + data_->data.Mass.residualFuelMass
                                    << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td></td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "<tr>" << std::endl
                                    << "<td>---</td><td>not Alloc</td><td>" << data_->data.Mass.notAllocatedSystems << " kg</td>" << std::endl
                                    << "</tr>" << std::endl
                                    << "</table>" << std::endl
                                    << "</div>" << std::endl
                                    << "<div id=\"rightCol\">" << std::endl
         //Graphic:
                                    << "<img class=\"image-plot\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                       "_SystemsMass_plot.svg\">" << std::endl
                                    << "</div>" << std::endl;
      } else {
         report_.htmlReportStream() << "<td>The program was run in analysis mode..</td>" << std::endl
                                    << "<td>The masses were not redetermined!</td>" << std::endl;
      }
/* Mission Profile Section */
      report_.htmlReportStream() << "<!-- CeRAS Report Systems -->" << std::endl
                                 << "<!-- ################################################################################################### -->" << std::endl
                                 << "<div id=\"wrapper\">" << std::endl
                                 << "<div id=\"leftCol\">" << std::endl
//    std::string missionFile(myAcftPt->myMissionPt->missionFile.substr(myAcftPt->myMissionPt->missionFile.find_last_of('\\') + 1))
//    report << "<h1>Mission: " << missionFile << "</h1>" << std::endl
                                 << "<h2>Required Power during the Mission</h2>" << std::endl
                                 << "<font size=\"-1\">Values at the end of the mission step are given in each case.</font>" << std::endl
                                 << "<img class=\"image-plot\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                    "_MissionSteps_plot.svg\">" << std::endl
                                 << "<img class=\"image-plot\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                    "_accumulatedPower_plot.svg\">" << std::endl
                                 << "</div>" << std::endl
                                 << "<div id=\"rightCol\">" << std::endl
/* Off-takes from energy sources */
                                 << "<h2>Power Off-takes</h2>" << std::endl;
      for (size_t n = 0; n < data_->Systems.energySource.size(); n++) {
      report_.htmlReportStream() << "<img class=\"image-plot\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                    "_MissionPower_" + data_->Systems.energySource.at(n)->ATA + "_plot.svg\">" << std::endl;
      }
      report_.htmlReportStream() << "<font size=\"-1\">APU is sized (only) for ground operations at gate (not visible in this mission).</font>" << std::endl
                                 << "</div>\n"
                                 << "</div>" << std::endl
/* Mission power of energy conductors */
                                 << "<h2>Energy Conductors</h2>" << std::endl;
      for (size_t n = 0; n < data_->Systems.energyConductor.size(); n++) {
         report_.htmlReportStream() << "<img class=\"ceras2Col\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                 "_MissionPower_" + data_->Systems.energyConductor.at(n)->ATA + "_plot.svg\">" << std::endl;
      }
/* Mission power of energy sinks */
      report_.htmlReportStream() << "<h2>Energy Sinks</h2>" << std::endl;
      for (size_t n = 0; n < data_->Systems.energySink.size(); n++) {
      report_.htmlReportStream() << "<img class=\"ceras2Col\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                    "_MissionPower_" + data_->Systems.energySink.at(n)->ATA + "_plot.svg\">" << std::endl;
      }
/* Design Power Section */
      report_.htmlReportStream() << "<h2>Design Power: </h2>" << std::endl
                                 //<< "<div class=\"box plot\">\n"
                                 << "<img class=\"ceras2Col\" src=\"" + relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()) + "/" + data_->configuration.theProgramName +
                                    "_EnergySinksMaxEnergy_plot.svg\">" << std::endl
                                 << "</div>\n"
                                 << "<!-- ################################################################################################### -->" << std::endl;
}

void standardSystemsDesign::setTexBody() {
    if (data_->configuration.designCase == true) {
        report_.texReportStream() << "\\section{Systems Design}" << std::endl;
    }
    if (data_->configuration.designCase && !data_->configuration.texReportWithoutMasses) {
        report_.texReportStream() << "\\begin{frame}" << std::endl
                                   << " \\frametitle{Mass Breakdown}" << std::endl
                                   << std::endl
                                   << std::endl
                                   << " \\begin{table}" << std::endl
                                   << " \\centering" << std::endl
                                   << " \\scriptsize" << std::endl
                                   << "     \\begin{tabularx}{230pt}{llrr}" << std::endl
                                   << "        \\multicolumn{4}{c}{Program Mode: " << std::endl
                                   << "        \\textit{Sizing Mode}}\\\\" << std::endl
                                   << "        \\midrule[0.5pt]" << std::endl
                                   << "        \\multicolumn{4}{l}{Empty Weights}\\\\" << std::endl
                                   << "        \\midrule[0.5pt]" << std::endl
                                   << "          Operating Mass Empty & OME & " << Rounding(data_->data.Mass.OME, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Previous Operating Mass Empty & OME$_{prev}$ & " << Rounding(data_->data.Mass.OME, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Manufacturer's Mass Empty & MME & " << Rounding(data_->data.Mass.MME, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "        \\midrule[0.5pt]" << std::endl
                                   << "        \\multicolumn{4}{l}{Component Weights}\\\\" << std::endl
                                   << "        \\midrule[0.5pt]" << std::endl
                                   << "          Structures & m$_{structure}$ & " << Rounding(data_->data.Mass.Structure, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Gear & m$_{gear}$ & " << Rounding(data_->data.Mass.Gear, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Propulsion & m$_{propulsion}$ & " << Rounding(data_->data.Mass.totalGroupAllEngines, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Systems & m$_{systems}$ & " << Rounding(data_->data.Mass.systemsGroup, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Not Allocoated Mass & m$_{miscellaneous}$ & "
                                      << Rounding(data_->data.Mass.notAllocatedSystems, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "     \\end{tabularx}" << std::endl
                                   << " \\end{table}" << std::endl
                                   << std::endl
                                   << " \\begin{figure}" << std::endl
                                   << "     \\tiny" << std::endl
                                   << "     \\def\\svgwidth{5.5cm}" << std::endl
                                   << "     \\import{" + win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()))
                                                       + "}{" + data_->configuration.theProgramName + "_MassBreakdown_plot.pdf_tex}" << std::endl
                                   << "     \\caption{\\scriptsize{Mass breakdown}}" << std::endl
                                   << " \\end{figure}" << std::endl
                                   << std::endl
                                   << "\\end{frame}" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << std::endl

                                   << "\\begin{frame}" << std::endl
                                   << " \\frametitle{Systems Masses}" << std::endl
                                   << std::endl
                                   << std::endl
                                   << " \\begin{table}" << std::endl
                                   << " \\centering" << std::endl
                                   << " \\footnotesize" << std::endl
                                   << "     \\begin{tabularx}{260pt}{llrr}" << std::endl
                                   << "        \\toprule" << std::endl
                                   << "        \\textcolor{ilrdark}{System} & \\textcolor{ilrdark}{ATA No.} & \\textcolor{ilrdark}{Value} &\\textcolor{ilrdark}{Unit} \\\\"
                                      << std::endl
                                   << "        \\midrule[0.5pt]" << std::endl
                                             //\\textcolor{ilrdark}{$\\blacktriangleright$}
                                   << "          Air Conditioning & ATA-21 & "
                                      << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-21"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Electric System & ATA-24 & "
                                      << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-24"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Furnishing & ATA-25 & " << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-25"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Fire Protection & ATA-26 & "
                                      << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-26"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Fuel System & ATA-28 & "
                                      << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-28"))->Mass, 0) << "& $\\kilogram$\\\\" << std::endl
                                   << "          Hydraulic System & ATA-29 & "
                                      << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-29"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Anti Icing & ATA-30 & "
                                      << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-30"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Lighting & ATA-33 & " << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-33"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Oxygen & ATA-35 & " << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-35"))->Mass, 0)
                                      << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Bleed Air & ATA-36 & " << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-36"))->Mass, 0)
                                   << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Auxiliary Power Unit (APU) & ATA-49 & "
                                   << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-49"))->Mass, 0)
                                   << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Remaining consumers & ATA-XX & "
                                   << Rounding(data_->Systems.allSystems.at(data_->Systems.getSpecificSystem("ATA-XX"))->Mass, 0)
                                   << "& $\\kilogram$ \\\\" << std::endl
                                   << "          Not Allocated Mass &  & " << Rounding(data_->data.Mass.notAllocatedSystems, 0) << "& $\\kilogram$ \\\\" << std::endl
                                   << "        \\bottomrule" << std::endl
                                   << "     \\end{tabularx}" << std::endl
                                   << " \\end{table}" << std::endl
                                   << "\\end{frame}" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << "\\begin{frame}" << std::endl
                                   << " \\frametitle{Systems Masses}" << std::endl
                                   << std::endl
                                   << std::endl
                                   << " \\begin{figure}" << std::endl
                                   << "     \\tiny" << std::endl
                                   << "     \\def\\svgwidth{10cm}" << std::endl
                                   << "     \\import{" + win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getIODir()))
                                              + "}{" + data_->configuration.theProgramName + "_SystemsMass_plot.pdf_tex}" << std::endl
                                   << "     \\caption{\\scriptsize{ATA Systems Masses}}" << std::endl
                                   << " \\end{figure}" << std::endl
                                   << "\\end{frame}" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << std::endl;
    }
    report_.texReportStream() << "\\begin{frame}" << std::endl
                               << " \\frametitle{Mission Increments for Systems Off-takes}" << std::endl
                               << "     \\begin{figure}" << std::endl
                               << "     \\tiny" << std::endl
                               << "     \\def\\svgwidth{7cm}" << std::endl
                               << "     \\import{" +
                                                 win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir())) + "}{" +
                                                 data_->configuration.theProgramName + "_MissionSteps_plot.pdf_tex}" << std::endl
                               << "         \\caption{\\scriptsize{Mission increments and flight conditions}}" << std::endl
                               << "     \\end{figure}" << std::endl
                               << std::endl
                               << "\\scriptsize{Values at the end of the mission step are given in each case.}" << std::endl
                               << std::endl
                               << "\\end{frame}" << std::endl
                               << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                               << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                               << std::endl
                               << "\\begin{frame}" << std::endl
                               << " \\frametitle{Energy Sources}" << std::endl
                               << "     \\begin{figure}" << std::endl
                               << "         \\tiny" << std::endl
                               << "         \\def\\svgwidth{7cm}" << std::endl
                               << "         \\import{" + win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir())) + "}{"
                                                       + data_->configuration.theProgramName + "_missionPower_EnergySources_plot.pdf_tex}" << std::endl
                               << "         \\caption{\\scriptsize{Power off-takes energy sources (propulsion and APU)}}" << std::endl
                               << "     \\end{figure}" << std::endl
                               << std::endl
                               << "\\scriptsize{APU is sized (only) for ground operations at gate (not visible in this mission).}" << std::endl
                               << std::endl
                               << "\\end{frame}" << std::endl
                               << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                               << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                               << std::endl
                               << "\\begin{frame}" << std::endl
                               << " \\frametitle{Energy Conductors and Accumulated Off-takes}" << std::endl
                               << "     \\begin{figure}" << std::endl
                               << "         \\tiny" << std::endl
                               << "         \\def\\svgwidth{10cm}" << std::endl
                               << "         \\import{" + win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir())) + "}{"
                                                       + data_->configuration.theProgramName + "_missionPower_EnergyConductors_plot.pdf_tex}" << std::endl
                               << "         \\caption{\\scriptsize{Power off-takes energy conductors and sinks (accumulated)}}" << std::endl
                               << "     \\end{figure}" << std::endl
                               << std::endl
                               << "\\end{frame}" << std::endl
                               << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                               << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl;
    if (data_->configuration.designCase) {
        report_.texReportStream() << "\\begin{frame}" << std::endl
                                   << " \\frametitle{Maximum Energy}" << std::endl
                                   << "     \\begin{figure}" << std::endl
                                   << "         \\tiny" << std::endl
                                   << "         \\def\\svgwidth{10cm}" << std::endl
                                   << "         \\import{" + win2lin(relativePath(rtIO_->getPlotDir(), rtIO_->getReportDir()))
                                                           + "}{" + data_->configuration.theProgramName + "_EnergySinksMaxEnergy_plot.pdf_tex}" << std::endl
                                   << "         \\caption{\\scriptsize{Maximum energy ATA systems}}" << std::endl
                                   << "     \\end{figure}" << std::endl
                                   << std::endl
                                   << "\\end{frame}" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl
                                   << "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" << std::endl;
    }
}
