# UNICADO - UNIversity Conceptual Aircraft Design and Optimization
#
# Copyright (C) 2024 UNICADO consortium
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# Description:
# This file is part of UNICADO.

"""Module providing export functionalities for current calculation method."""
# Import standard libraries.
import xml.etree.ElementTree as ET

# Import own modules.
from datapostprocessingmodule import create_element_tree_from_paths
from datapostprocessingmodule import convert_dictionary_to_element_tree


def method_xml_export(paths_and_names, routing_dict, data_dict, method_specific_output_dict, xml_export_tree,
                      path_to_results_file, runtime_output):
    """Export function.

    This function is responsible for the export of method-specific data to the corresponding method-specific XML. In
    detail, this includes the following steps:
        (1) Parse the XML file specified by the 'path_to_results_file' variable.
        (2) Find the 'calculation_results' element in the XML file. This is the element under which method-specific
        nodes will be added.
        (3) Extract method-related information from the configuration file, such as the method name and description and
        add method node.
        (4) Extract design mission data from the method-specific output dictionary and write it to the XML file.
        (5) If a study exists, extract study data from the method-specific output dict and write it to the XML file.
        (6) Attempt to write the modified XML data back to the 'costEstimation_results.xml' file. Handle an OSError
        exception in case an error occurs during this operation.

    :param dict paths_and_names: Dictionary containing system paths and ElementTrees
    :param dict routing_dict: Dictionary containing routing parameters
    :param dict data_dict: Dictionary containing results of module execution
    :param dict method_specific_output_dict: Dictionary containing method-specific output data
    :param ElementTree xml_export_tree: Element tree of method-specific XML tree
    :param str path_to_results_file: Path to method-specific output XML file
    :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
    :raises OSError: Raised if writing to aircraft exchange file failed
    :return: None
    """
    runtime_output.print("XML report was generated, but no method-specific data was written.")

