# Getting started {#getting-started}
Welcome to the Wing Design Tool! This section will guide you through the initial steps to access and begin using the tool.
This guide gives you a step-by-step overview of the parameters which affects the basic module behavior.

## Method selection
The main method selection, _which_ wing shall be designed comes from the _Aircraft Exchange File_. This is defined in the Block `requirements_and_specification` of the _Aircraft Exchange File_.

Here you have two main elements which will affect the wing design inside `design_specification/configuration`:
- `configuration_type`: This defines the aircraft configuration which the wing is build for
  - `tube_and_wing`
  - `blended_wing_body`

- `wing_definition`: This defines where the wing shall be mounted (no effect during BWB design)
  - `low`
  - `high`


The configuration file of the Wing Design tool `wing\_design_conf.xml`, gives you then more specified parameters to chose which will tailor the wing to your desire in the `program_settings` Block.

The file comes with mode selectors and associated parameters to set which can vary.

Parameters to chose:
- `wing_configuration`:
  - `mode_0: cantilever`: sets wing type to cantilever wing.

To select a tube and wing with a cantilever chose the following inside the aircraft exchange file
- `configuration_type` is set to `tube_and_wing`
- `wing_configuration` is set to `mode_0` which selects `cantilever`
  <pre class="mermaid">
 graph LR;
   A[Wing Design] ==> B[Tube and Wing];
   B==>C[Cantilever];
   A-->D[Blended Wing body]
   style B stroke-width:4px
   style C stroke:#0f0, stroke-width:4px
   </pre>

Each `wing_configuration`will have it's own block to chose parameters from.
<dl class="section todo">
<dt>Note</dt>
<dd>
For default values or ranges, you should check the description of the parameters or the allowed ranges inside the configuration file
</dd>
</dl>
<dl class ="section invariant">
<dt>Tip</dt>
<dd>If you are missing some of the terms in here - take a look at [basic concepts](basic-concepts.md).</dd>
</dl>
## Configuration parameters &rarr; Tube and Wing
In this section you find parameters for tube and wing methods.
### Cantilever calculation methods and parameters
_Geometry calculation methods_
  - `wing_area`: How to calculate the wing area
    - `mode_0: user_defined`: Set a wing area
    - `mode_1: by_loading_and_mtom`: Set wing area by wing loading
  -`sweep`: How to calculate the wing quarter chord sweep (constant over wing from root to tip)
    - `mode_0: user_defined`: Set a user defined quarter chord sweep
    - `mode_1: drag_divergence`: Computes the wing sweep by the usage of Korn's equation
      - `param: korn_technology_factor`: Technology factor for korns method
      - `param: delta_drag_divergence_to_mach_design`: Set the difference between the design mach and the delta to the drag divergence mach number
  - `taper_ratio`: How to calculate the wings taper ratio
    - `mode_0: user_defined`: Set a taper ratio
    - `mode_1: howe`: Calculates the taper ratio by Howe's empirical method
  - `dihedral`: How to calculate the wings dihedral (root to tip; negative values &rarr; anhedral)
    - `mode_0: user_defined`: Set dihedral
    - `mode_1: by_wing_position_and_quarter_chord_sweep`: Calculates dihedral by vertical position (ref. to `wing_definition`) and the quarter chord sweep
      - `param: dihedral_limitation`: Chose from Raymer or How to set the dihedral limits
        - `mode_0: raymer`: Raymer's limits
        - `mode_1: howe`: Howe's limits
  - `aspect_ratio`: How to calculate aspect ratio
    - `mode_0: user_defined`: Set wing aspect ratio
    - `mode_1: by_pitch_up_limit_function`: Sets the aspect ratio by a predefined pitch up limit function (function parameters currently fix)
  - `relative_kink_position`: How to calculate the relative kink position (takes effect only when `wing_definition` is `low`)
    - `mode_0: user_defined`: Set relative kink position as part of dimensionless half span
      - `param: relative_kink_position`: relative kink position
      - `param: maximum_inner_trailing_edge_sweep`: sets the maximum inner wing trailing edge sweep.
    - `mode_1: based_on_landing_gear_track`: Calculate kink position on landing gear track (no effect - future implementation)
      - `param: initial_relative_kink_position`: initial relative kink position (first iteration)
      - `param: maximum_inner_trailing_edge_sweep`: sets the maximum inner wing trailing edge sweep.
  - `wing_profile_and_thickness_distribution`:
    - `mode_0: user_defined`: Sets user defined profiles with associated thickness to chord ratios (multiple ID Elements)
      - `param: wing_profile`: Name of desired airfoil
      - `param: thickness_to_chord/ratio`: thickness to chord ratio for the desired profile
      - `param: thickness_to_chord/at_half_span`: dimensionless half span position where to apply the airfoil
    - `mode_1: torenbeek_jenkinson`: Torenbeek-Jenkinson method to determine thickness distribution
      - `param: wing_profiel`: Name of desired airfoil
      - `param: max_thickness_to_chord_ratio`: Maximum thickness to chord ratio (at root / centerline)
      - `param: airfoil_critical_factor`: Sets technology level

_Mass Calculation Methods_
  - `mass`: How to calculate the mass methods
    - `mode_0: flops`: Calculate the wing mass according to FLOPS (_NASA Flight Optimization System_)
      - `param: fstrt`: Wing strut bracing factor
      - `param: faert`: Wing aeroelastic tailoring factor
      - `param: fcomp`: Wing composite utilization factor
    - `mode_1: chiozzotto_wer`: Calculate the wing mass according to Chiozzotto (WER)
      - `param: technology_factor`: Technology factor, scales effective weight
      - `param: material`: Material to chose between Aluminium or Carbo Fiber Reinforced Plastic

_Control Design Methods_
 - `mode_0: user_defined`: User defined control devices (multiple ID Elements)
   - `param: type`: Sets type of control device (e.g. aileron, rudder, elevator...)
   - `param: deflection`: Set positive and negative deflection limits
   - `param: position`: Set position parameters like chordwise and spanwise position for inner and outer dimension of a control device
 - `mode_1: empirical`: Sets control devices according to standard values
   - `param: high_lift_device_type_leading_edge`: Select high lift leading edge device type
   - `param: high_lift_device_type_trailing_edge`: Select high lift trailing edge device type

_Spars Methods_
 - `mode_0: user_defined`: Sets spars directly (multiple ID Elements)
   - `param: name`: Set spar name (e.g. front spar, rear spar etc.)
   - `param: position`: Set position parameters like chordwise and spanwise position for inner and outer dimension of a spar

## Configuration parameters &rarr; Blended Wing Body
In this section you find parameters for Blended Wing Body methods.

<dl class="section todo">
<dt>Note</dt>
<dd>In the beta version of UNICADO, BWB methods are under development</dd>
</dl>

## Additional configurations
Additionally, one has to define the common airfoil data paths inside the configuration file:
- `common_airfoil_data_paths`: Defines the path, where to look for airfoils - normally a database

## Additional information and requirements
The methods in the wing design tool also require additional information on the design mach number, and the ICAO aerodrome reference code (for determination of maximum allowed span) from the requirements and specification block of the _Aircraft Exchange File_.

<dl class="section bug">
<dt>Important</dt>
<dd>
 Keep in mind that the _wing\_design_ tool generates a wing as a part of an aircraft. This lets it rely on specific values, e.g. for definining the area inside the fuselage etc. This leads to mandatory items at this point:

 - A specified fuselage - here length and width and height are necessary to determine wing geometry and wing position
 - Initial Maximum Takeoff Mass (MTOM) - for determination of the wing area necessary based on the wing loading (only if method is selected)
</dd>
Please keep in mind, that the module is still in beta phase and you can gratefully contribute to the

## Next Steps
The next step is to run the _wing\_design_ tool. So let's get your wings from [Design your first wing](dfw.md)
