/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#include "wingAreaMethods.h"

#include <functional>
#include <iostream>
#include <map>

double user_defined::wing_area(const double user_data) { return user_data; }

double loading_and_mass::wing_area(const double mtom, const double loading) { return mtom / loading; }

double get_design_wing_area(modes wing_area_mode, const double user_wing_area, const double maximum_takeoff_mass,
                            const double wing_loading) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> wing_area_selection = {
      {"mode_0", {"user_defined", [=]() { return user_defined::wing_area(user_wing_area); }}},
      {"mode_1", {"by_loading_and_mtom", [=]() {
                    return loading_and_mass::wing_area(maximum_takeoff_mass, wing_loading);
                  }}}};  // namespace taw
  const auto [method, area_method] = wing_area_selection[wing_area_mode];
  const double area = area_method();
  std::cout << "Wing area [method]: " << method << "\n";
  std::cout << "Wing area  [value]: " << area << " [m^2]\n";
  return area;
}