/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef WING_PROFILE_AND_THICKNESS_DISTRIBUTION_METHODS_H_
#define WING_PROFILE_AND_THICKNESS_DISTRIBUTION_METHODS_H_

#include <string>
#include <tuple>
#include <vector>
using modes = std::string;

namespace user_defined {
std::vector<std::tuple<double, double, std::string>> wing_profile_and_thickness_distribution(
    const std::vector<std::tuple<double, double, std::string>> user_wing_profiles_and_thickness_to_chord,
    const double eta_fuselage, std::vector<double> eta_positions);
}

namespace torenbeek_jenkinson {
std::vector<std::tuple<double, double, std::string>> wing_profile_and_thickness_distribution(
    const std::string& wing_profile, const double maximum_thickness_to_chord_ratio,
    const double technology_factor_airfoil, const double mach_design, const double design_altitude,
    const double quarter_chord_sweep, const double mach_drag_divergence, const double wing_loading,
    const double eta_fuselage, std::vector<double> eta_positions);
}  // namespace torenbeek_jenkinson

std::vector<std::tuple<double, double, std::string>> get_wing_profile_and_thickness(
    modes wing_profile_and_thickness,
    const std::vector<std::tuple<double, double, std::string>> user_wing_profile_and_thickess,
    const std::string& wing_profile, const double maximum_thickness_to_chord_ratio,
    const double technology_factor_airfoil, const double mach_design, const double design_altitude,
    const double quarter_chord_sweep, const double mach_drag_divergence, const double wing_loading,
    const double eta_fuselage, std::vector<double> eta_positions);

#endif  // WING_PROFILE_AND_THICKNESS_DISTRIBUTION_METHODS_H_
