/*
 * UNICADO - UNIversity Conceptual Aircraft Design and Optimization
 *
 * Copyright (C) 2024 UNICADO consortium
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 *
 * Description:
 * This file is part of UNICADO.
 */

#ifndef RELATIVE_POSITION_IO_H_
#define RELATIVE_POSITION_IO_H_

#include <aixml/endnode.h>

class RelativePosition {
 public:
  RelativePosition() = default;
  RelativePosition(const std::string& origin)
      : inner_position_spanwise(EndnodeReadOnly<double>(origin + "position/inner_position/spanwise")),
        inner_position_chord_from(EndnodeReadOnly<double>(origin + "position/inner_position/chord/from")),
        inner_position_chord_to(EndnodeReadOnly<double>(origin + "position/inner_position/chord/to")),
        outer_position_spanwise(EndnodeReadOnly<double>(origin + "position/outer_position/spanwise")),
        outer_position_chord_from(EndnodeReadOnly<double>(origin + "position/outer_position/chord/from")),
        outer_position_chord_to(EndnodeReadOnly<double>(origin + "position/outer_position/chord/to")) {}
  EndnodeReadOnly<double> inner_position_spanwise;
  EndnodeReadOnly<double> inner_position_chord_from;
  EndnodeReadOnly<double> inner_position_chord_to;
  EndnodeReadOnly<double> outer_position_spanwise;
  EndnodeReadOnly<double> outer_position_chord_from;
  EndnodeReadOnly<double> outer_position_chord_to;

  void read(const node& xml) {
    inner_position_spanwise.read(xml);
    inner_position_chord_from.read(xml);
    inner_position_chord_to.read(xml);
    outer_position_spanwise.read(xml);
    outer_position_chord_from.read(xml);
    outer_position_chord_to.read(xml);
  }
};

#endif  // RELATIVE_POSITION_IO_H_